@@ -98,14 +98,13 @@ async def _gracefully_retry(
 
     failing = True
     while failing:
-        if retry.log_before:
-            process_log_retry(retry.log_before, DefaultLogMessage.RETRY_BEFORE, request_context, state)
-
         state.increment()
-
         if state.cant_retry:
             break
 
+        if retry.log_before:
+            process_log_retry(retry.log_before, DefaultLogMessage.RETRY_BEFORE, request_context, state)
+
         await sleep(state.delay)
         await _gracefully_throttle(throttle_controller, request_context)
         throttle_controller.init_request(request_context)
@@ -137,7 +136,13 @@ def _check_strictness(active_config: GracyConfig, result: httpx.Response) -> boo
     return True
 
 
-def _check_allowed(active_config: GracyConfig, result: httpx.Response) -> bool:
+def _check_allowed(active_config: GracyConfig, result: httpx.Response, strict_pass: bool | None = None) -> bool:
+    if strict_pass is False:
+        # We do this because we don't have to check allowed statuses if strict failed
+        # Otherwise retry logic might be triggered twice
+        # If this is None we assume strict pass either passed or is unset
+        return True
+
     successful = result.is_success
     if not successful and active_config.allowed_status_code:
         if not isinstance(active_config.allowed_status_code, Unset):
@@ -216,7 +221,7 @@ async def _gracify(
         if must_break:
             raise UnexpectedResponse(str(result.url), result, strict_codes)
 
-    allowed_pass = _check_allowed(active_config, result)
+    allowed_pass = _check_allowed(active_config, result, strict_pass=strict_pass)
     if allowed_pass is False:
         retry_result = None
         must_break = True
@@ -259,7 +264,7 @@ class Gracy(Generic[Endpoint]):
         SETTINGS: GracyConfig = DEFAULT_CONFIG
 
     def __init__(self, replay: GracyReplay | None = None, **kwargs: Any) -> None:
-        self._base_config: GracyConfig = getattr(self.Config, "SETTINGS", DEFAULT_CONFIG)
+        self._base_config = cast(GracyConfig, getattr(self.Config, "SETTINGS", DEFAULT_CONFIG))
         self._client = self._create_client(**kwargs)
         self._replay = replay
 
@@ -380,6 +385,15 @@ class Gracy(Generic[Endpoint]):
         report = self.get_report()
         print_report(report, printer)
 
+    @classmethod
+    def dangerously_reset_report(cls):
+        """
+        Doing this will reset throttling rules and metrics.
+        So be sure you know what you're doing.
+        """
+        cls._throttle_controller = ThrottleController()
+        cls._reporter = ReportBuilder()
+
 
 ANY_COROUTINE = Coroutine[Any, Any, Any]
 
